/*
 *  XMail by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999,..,2004  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davidel@xmailserver.org>
 *
 */

#ifndef _XMCOMMTYPES_H
#define _XMCOMMTYPES_H


struct FileSection {
	char szFilePath[SYS_MAX_PATH];
	SYS_OFF_T llStartOffset;
	SYS_OFF_T llEndOffset;
};

struct Datum {
	char *pData;
	long lSize;
};

struct LstDatum {
	SysListHead LLnk;
	Datum Data;
};

struct LstNDatum {
	SysListHead LLnk;
	Datum Name;
	Datum Data;
};


#endif
